@@ -1,4 +1,4 @@
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
 
 from django.conf import settings
@@ -7,7 +7,12 @@ from .replacer import replace_call
 
 SQL_STACKTRACE = settings.SQL_STACKTRACE if hasattr(settings, 'SQL_STACKTRACE') else False
 if SQL_STACKTRACE:
-    from django.db.backends.base.base import BaseDatabaseWrapper
+    try:
+        # Django 1.8+
+        from django.db.backends.base.base import BaseDatabaseWrapper
+    except ImportError:
+        # Django<=1.7
+        from django.db.backends import BaseDatabaseWrapper
     from .stacktracecursor import StacktraceCursorWrapper
 
     @replace_call(BaseDatabaseWrapper.cursor)
